from . import base

class DynamoDBDataNode(base.TypedDataPipelineObject): pass


class MySqlDataNode(base.TypedDataPipelineObject): pass


class RedshiftDataNode(base.TypedDataPipelineObject): pass


class S3DataNode(base.TypedDataPipelineObject): pass


class SqlDataNode(base.TypedDataPipelineObject): pass